@@ -13,7 +13,8 @@ from ..functions import dp
 from ..resources.language import Text
 from .measurement_import import Measurement
 from .ptw_import import PTWMultimporter
-from .sim_import import EGSSimulation, Simulation
+from .sim_import import Simulation
+from .egs_import import EGSSimulation
 
 
 class DoseFigureHandler:
@@ -197,12 +198,13 @@ class DoseFigureHandler:
                     data[0][0], data[1][0], data[1][1], left=0, right=0
                 )
             difference = [
-                100 * (interpolated_data[i] - data[0][1][i]) / (data[0][1][i])
+                (interpolated_data[i] - data[0][1][i])  # / (data[0][1][i])
                 for i in range(len(data[0][0]))
             ]
 
             difference[:] = [x if round(x, 1) != -100 else 0 for x in difference]
             difference[:] = [x if round(x, 1) != 100 else 0 for x in difference]
+
             self.diffax.plot(
                 data[0][0],
                 difference,
@@ -211,7 +213,7 @@ class DoseFigureHandler:
                 label=self.text.error[self.lang],
             )
             if self.errlim == None:
-                self.errlim = [min(difference) - 1, max(difference) + 1]
+                self.errlim = [min(difference) - 0.01, max(difference) + 0.01]
             self.diffax.set_ylim(self.errlim)
             self.diffax.legend(
                 loc="upper right",
